.. :changelog:

History
-------

0.1.1 (2015-05-01)
------------------

* Support more complex string-type schemas
* Attempt to infer JSON lines format instead of just failing
* API cleanup: no need for long imports anymore
* Updated documentation, added docstrings
* Fixed merging schema for arrays with tuple vs list validation
* Fixed compatibility issues with Python 2.6
* Improved test coverage, added end-to-end tests


0.1.0 (2015-03-03)
---------------------

* First release on PyPI.
